@@ -1,5 +1,5 @@
 # noinspection PyUnresolvedReferences
-from asyncio import coroutine, Future
+from asyncio import Future
 from functools import cmp_to_key
 from . import connection, protocol, client, features
 from .client import Error, NotInChannel, AlreadyInChannel, BasicClient, ClientPool
